
/* Chrysalide - Outil d'analyse de fichiers binaires
 * preferences.c - (re)définition de l'identité de l'utilisateur
 *
 * Copyright (C) 2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Chrysalide.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "preferences.h"


#include <i18n.h>



/* Eléments de la liste de sections */
typedef enum _PrefListItem
{
    PLI_TITLE,                              /* Etiquette de la section     */
    PLI_PANEL,                              /* Panneau graphique associé   */

} PrefListItem;



/******************************************************************************
*                                                                             *
*  Paramètres  : parent = fenêtre principale de l'éditeur.                    *
*                outb   = constructeur à détruire après usage. [OUT]          *
*                                                                             *
*  Description : Propose une boîte de dialogue pour la configuration générale.*
*                                                                             *
*  Retour      : Adresse de la fenêtre mise en place.                         *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

GtkWidget *create_preferences_dialog(GtkWindow *parent, GtkBuilder **outb)
{
    GtkWidget *result;                      /* Fenêtre à renvoyer          */
    GtkBuilder *builder;                    /* Constructeur utilisé        */
    GtkTreeStore *store;                    /* Arborescence des sections   */
    GtkTreeIter iter;                       /* Point d'insertion           */

    builder = gtk_builder_new_from_resource("/org/chrysalide/gui/dialogs/preferences.ui");
    *outb = builder;

    result = GTK_WIDGET(gtk_builder_get_object(builder, "window"));

    gtk_window_set_transient_for(GTK_WINDOW(result), parent);

    /* Intégration des différentes sections */

    store = GTK_TREE_STORE(gtk_builder_get_object(builder, "pref_list"));

    gtk_tree_store_append(store, &iter, NULL);

    gtk_tree_store_set(store, &iter,
                       PLI_TITLE, _("Colored labels"),
                       PLI_PANEL, gtk_builder_get_object(builder, "colored_labels_panel"),
                       -1);

    /* Mise à jour de l'interface */

    /* Connexion des signaux */

    /*
    gtk_builder_add_callback_symbols(builder,
                                     "update_preferences", G_CALLBACK(update_preferences),
                                     NULL);
    */

    gtk_builder_connect_signals(builder, builder);

    return result;

}
